@@ -658,7 +658,6 @@ def complete_xontrib(prefix, line, start, end, ctx):
 #
 # _aliases
 #
-inspect = _LazyModule.load('inspect', 'inspect')
 # amalgamated builtins
 collections = _LazyModule.load('collections', 'collections')
 # amalgamated xonsh.lazyasd
@@ -694,7 +693,7 @@ def _add_one_completer(name, func, loc='end'):
     builtins.__xonsh_completers__.update(new)
 
 
-def _list_completers(args, stdin=None):
+def _list_completers(args, stdin=None, stack=None):
     o = "Registered Completer Functions: \n"
     _comp = builtins.__xonsh_completers__
     ml = max((len(i) for i in _comp), default=0)
@@ -709,7 +708,7 @@ def _list_completers(args, stdin=None):
     return o + '\n'.join(_strs) + '\n'
 
 
-def _remove_completer(args, stdin=None):
+def _remove_completer(args, stdin=None, stack=None):
     err = None
     if len(args) != 1:
         err = "completer remove takes exactly 1 argument."
@@ -725,7 +724,7 @@ def _remove_completer(args, stdin=None):
         return None, err + '\n', 1
 
 
-def _register_completer(args, stdin=None):
+def _register_completer(args, stdin=None, stack=None):
     err = None
     if len(args) not in {2, 3}:
         err = ("completer add takes either 2 or 3 arguments.\n"
@@ -742,8 +741,7 @@ def _register_completer(args, stdin=None):
                 if not callable(func):
                     err = "%s is not callable" % func_name
             else:
-                print(inspect.stack(context=0))
-                for frame_info in inspect.stack(context=0):
+                for frame_info in stack:
                     frame = frame_info[0]
                     if func_name in frame.f_locals:
                         func = frame.f_locals[func_name]
@@ -760,7 +758,8 @@ def _register_completer(args, stdin=None):
         return None, err + '\n', 1
 
 
-def completer_alias(args, stdin=None):
+def completer_alias(args, stdin=None, stdout=None, stderr=None, spec=None,
+                    stack=None):
     err = None
     if len(args) == 0 or args[0] not in (VALID_ACTIONS | {'help'}):
         err = ('Please specify an action.  Valid actions are: '
@@ -785,7 +784,7 @@ def completer_alias(args, stdin=None):
         func = _remove_completer
     elif args[0] == 'list':
         func = _list_completers
-    return func(args[1:], stdin=stdin)
+    return func(args[1:], stdin=stdin, stack=stack)
 
 COMPLETER_LIST_HELP_STR = """completer list: ordered list the active completers
 
@@ -1294,7 +1293,7 @@ def complete_dir(prefix, line, start, end, ctx, cdpath=False):
 """Completers for Python code"""
 # amalgamated re
 # amalgamated sys
-# amalgamated inspect
+inspect = _LazyModule.load('inspect', 'inspect')
 # amalgamated builtins
 importlib = _LazyModule.load('importlib', 'importlib')
 cabc = _LazyModule.load('collections', 'collections.abc', 'cabc')
